==> inca_tool-1.1.2-py3-none-any.whl: inca/tourism/postprocessing/post-process-results-series2021.py <==
import os
import rasterio
import inca.common.classification as classification
import numpy as np


def correct_nan_value(input_file,output_file):
    """

    """
    # Open the input raster file for reading
    with rasterio.open(input_file) as src:
        # Read the raster data into a NumPy array
        raster_data = src.read(1)  # Assuming it's a single-band raster

        # Replace 0 values with NaN
        raster_data[raster_data == 0] = -32768

        # Get the metadata of the input raster
        profile = src.profile

        # Open the output raster file for writing with updated values
        with rasterio.open(output_file, 'w', **profile) as dst:
            # Write the modified raster data
            dst.write(raster_data, 1)  # Assuming it's a single-band raster

# raster inlezen
dataloc = r"C:\Dfold\inca2021series\output"
folders = r"tourism2021_fullseries_{}"
years = [2000,2006,2012,2018,2021]
files = ["tourism_map_supply_amountOvernightStays_{}.tif",
         "tourism_map_supply_amountOvernightStays-foreign_{}.tif",
         "tourism_map_supply_amountOvernightStays-national_{}.tif"]
for year in years:
    print(year)
    # Specify the path of the new folder
    new_folder_path = f2r = os.path.join(dataloc,folders.format(year),"maps_corrected")

    # Check if the folder already exists
    if not os.path.exists(new_folder_path):
        # Create the new folder
        os.makedirs(new_folder_path)
        print(f"Folder '{new_folder_path}' created successfully.")
    else:
        print(f"Folder '{new_folder_path}' already exists.")
    for file in files:
        f2s = os.path.join(new_folder_path,file.format(year))
        print(file)
        f2r = os.path.join(dataloc,folders.format(year),"maps",file.format(year))
        correct_nan_value(input_file=f2r,
                          output_file=f2s)

==> inca_tool-1.9.6-py3-none-any.whl: inca/tourism/postprocessing/post-process-results-series2021.py <==
import os
import rasterio
import inca.common.classification as classification
import numpy as np


def correct_nan_value(input_file,output_file):
    """

    """
    # Open the input raster file for reading
    with rasterio.open(input_file) as src:
        # Read the raster data into a NumPy array
        raster_data = src.read(1)  # Assuming it's a single-band raster

        # Replace 0 values with NaN
        raster_data[raster_data == 0] = -32768

        # Get the metadata of the input raster
        profile = src.profile

        # Open the output raster file for writing with updated values
        with rasterio.open(output_file, 'w', **profile) as dst:
            # Write the modified raster data
            dst.write(raster_data, 1)  # Assuming it's a single-band raster

# raster inlezen
dataloc = r"C:\Dfold\inca2021series\output"
folders = r"tourism2021_fullseriesRun4_{}"
years = [2000,2006,2012,2018,2021]
files = ["tourism_map_supply_amountOvernightStays_{}.tif",
         "tourism_map_supply_amountOvernightStays-foreign_{}.tif",
         "tourism_map_supply_amountOvernightStays-national_{}.tif"]
for year in years:
    print(year)
    # Specify the path of the new folder
    new_folder_path = f2r = os.path.join(dataloc,folders.format(year),"maps_corrected")

    # Check if the folder already exists
    if not os.path.exists(new_folder_path):
        # Create the new folder
        os.makedirs(new_folder_path)
        print(f"Folder '{new_folder_path}' created successfully.")
    else:
        print(f"Folder '{new_folder_path}' already exists.")
    for file in files:
        f2s = os.path.join(new_folder_path,file.format(year))
        print(file)
        f2r = os.path.join(dataloc,folders.format(year),"maps",file.format(year))
        correct_nan_value(input_file=f2r,
                          output_file=f2s)
